@@ -44,7 +44,6 @@ class Tree:
                 temp.right = self.__addNodeFunc(val,temp.right)
 
             balancefact = self.getBalanceFactor(temp,0)
-            print(temp.data,balancefact)
             if balancefact>1:
                 if val<temp.left.data:
                     return self.__rightRotate(temp)
@@ -110,6 +109,15 @@ class Tree:
             temp = temp.left
         return temp.data
     
+    def findMinNode(self,temp=None):
+        if temp is None:
+            temp = self.root
+            if temp is None:
+                return None
+        while temp.left is not None:
+            temp = temp.left
+        return temp
+    
     def findMax(self,temp=None):
         if temp is None:
             temp = self.root
@@ -149,7 +157,7 @@ class Tree:
                 node = temp
             
             elif node.left is not None and node.right is not None:
-                temp = self.findMin(node.right)
+                temp = self.findMinNode(node.right)
                 node.data = temp.data
                 node.right = self.__deleteNodeFunc(temp.data,node.right)
         balancefact = self.getBalanceFactor(node,0)
@@ -298,4 +306,4 @@ class Tree:
 # print("PreOrder Display")
 # tr.preOrderDisplay()
 # print("PostOrder Display")
-# tr.postOrderDisplay()
\ No newline at end of file
+# tr.postOrderDisplay()
