@@ -262,15 +262,33 @@ class RedBlackTree():
         else:
             return False, None
 
-    def minimum(self, node):
+    def minimum(self, node=None):
+        if node is None:
+            return self.minimum(node=self.root)
         while node.left != self.NULL:
             node = node.left
         return node
+    
+    def findMin(self, node=None):
+        if node is None:
+            return self.minimum(node=self.root)
+        while node.left != self.NULL:
+            node = node.left
+        return node.data
 
-    def maximum(self, node):
+    def maximum(self, node=None):
+        if node is None:
+            return self.maximum(node=self.root)
         while node.right != self.NULL:
             node = node.right
         return node
+    
+    def findMax(self, node=None):
+        if node is None:
+            return self.maximum(node=self.root)
+        while node.right != self.NULL:
+            node = node.right
+        return node.data
 
     def successor(self, x):
         if x.right != self.NULL:
@@ -380,7 +398,7 @@ class RedBlackTree():
     def getBalanceFactor(self,node=None,var=1):
         if node is None:
             if var==1:
-                node = self.root
+                return self.getBalanceFactor(node=self.root)
             else:
                 return 0
         else:
@@ -393,7 +411,10 @@ class RedBlackTree():
         self.delete_node(self.root, data)
 
     def printtree(self):
-        self.__print(self.root, "", True)
+        if self.root is None:
+            print("There are no nodes to display")
+        else:
+            self.__print(self.root, "", True)
 
 # rbtree = RedBlackTree()
 # rbtree.addNode("amay")
